<%-- $Id: configure.jsp 7957 2021-06-03 07:39:33Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Gregory Vincic
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	Configure the order and visibility of columns in a table of items.
	This page will use the TableColumn.getTableColumns(item) to retreive the
	list of all available columns for that item type and
	getSession().getSetting(item+".columns") to retreive a comma-separated
	list of the current order of visible columns.

	@param item The type of items in the table

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.Base"
	import="java.util.Set"
	import="java.util.TreeSet"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final Item itemType = Item.valueOf(request.getParameter("item_type"));
final String subContext = Values.getString(request.getParameter("subcontext"), "");
final String tableId = request.getParameter("table_id");
final boolean enableInheritedAnnotations = Values.getBoolean(request.getParameter("enableInheritedAnnotations"));
final boolean enableRelatedItemColumns = Values.getBoolean(request.getParameter("enableRelatedItemColumns"));
final boolean enableLinkedItemColumns = Values.getBoolean(request.getParameter("enableLinkedItemColumns"));
final boolean enableStickyColumn = Values.getBoolean(request.getParameter("enableStickyColumn"));
final ItemContext cc = sc.getCurrentContext(itemType, subContext);

final String defaultColumns = cc.getObject("defaultColumns");
final String defaultSticky = cc.getObject("defaultColumns.sticky");
final String settingName = Values.getString(request.getParameter("settingName"), "columns");
%>
	<base:page type="popup" title="Set column order and visibility">
	<base:head scripts="~configure.js" styles="toolbar.css" />
	<base:body>
		<h1>Set column order and visiblity <base:help helpid="columns.configure" /></h1>
		
		<div id="page-data" class="datacontainer"
			data-table-id="<%=tableId%>"
			data-default-columns="<%=HTML.encodeTags(defaultColumns) %>"
			data-default-sticky="<%=HTML.encodeTags(defaultSticky) %>"
			data-item-type="<%=itemType.name() %>"
			data-subcontext="<%=subContext %>"
			data-setting-name="<%=settingName %>"
			></div>
		
		<form name="columns">
		<div class="content bg-filled-50 bottomborder">
		<table style="width: 100%; height: 100%;">
		<%
		if (enableInheritedAnnotations || enableRelatedItemColumns || enableLinkedItemColumns)
		{
			%>
			<tr>
				<td colspan="4" style="vertical-align: top;">
				<tbl:toolbar subclass="bottomborder">
					<tbl:button 
						id="selectAnnotationTypes" 
						image="add.png"
						title="Add inherited annotations&hellip;" 
						tooltip="Add columns for inherited annotations" 
						visible="<%=enableInheritedAnnotations %>"
					 />
					<tbl:button 
						id="selectRelatedItemColumn" 
						image="add.png"
						title="Add parent or child item columns&hellip;" 
						tooltip="Add columns from parent or child items" 
						visible="<%=enableRelatedItemColumns %>"
					 />
					<tbl:button 
						id="selectLinkedItemColumn" 
						image="add.png"
						title="Add linked columns&hellip;" 
						tooltip="Add columns from linked items" 
						visible="<%=enableLinkedItemColumns %>"
					 />
				</tbl:toolbar>
				</td>
			</tr>
			<%
		}
		%>
		<tr>
			<td style="padding: 5px;">
				<base:buttongroup vertical="true">
					<base:button
						id="moveUp"
						image="move_up.png" 
						tooltip="Move up" 
						subclass="square"
						data-down="0"
					/>
					<base:button 
						id="moveDown"
						image="move_down.png" 
						tooltip="Move down" 
						subclass="square"
						data-down="1"
					/>
				</base:buttongroup>
			</td>
	
			<td style="width: 45%;">
				<b>Visible columns</b><br>
				<select name="visible" id="visible" multiple size="16" style="width: calc(100% - 10px);">
				</select>
			</td>
			<td style="padding: 5px;">
				<base:buttongroup vertical="true">
					<base:button
						id="moveLeft"
						image="move_left.png" 
						tooltip="Make the selected hidden column(s) visible" 
						subclass="square"
					/>
					<base:button 
						id="moveRight"
						image="move_right.png" 
						tooltip="Make the selected visible column(s) hidden" 
						subclass="square"
					/>
				</base:buttongroup>
			</td>
	
			<td style="width: 45%; padding-right: 5px;">
				<b>Hidden columns</b><br>
				<select name="hidden" id="hidden" multiple size="16" style="width: calc(100% - 10px);">
				</select>
			</td>
		</tr>
		<tr>
			<td></td>
			<%
			// The layout will be different depending on if the "Sticky column" option
			// is available or not
			if (enableStickyColumn)
			{
				// We display the "Sticky column" and "Presets" side-by-side
				%>
				<td>
				<b>Sticky column</b><br>
				<select name="sticky" id="sticky" style="width: calc(100% - 10px);"></select>
				</td>
				<td></td>
				<td>
				<b>Presets</b><br>
				<table style="width: 100%;">
				<tr>
				<td>
				<%
			}
			else
			{
				// We display the "Presets" centered
				%>
				<td colspan="3">
				<table style="margin-left: auto; margin-right: auto;">
				<tr>
				<td style="padding-right: 0.5em;"><b>Presets</b></td>
				<td>
				<%
			}
			%>
			<select name="presets" id="presets" style="width: calc(100% - 10px);">
				<option value="">-- predefined --
				<option value="all">All
				<option value="_minimal_">Required
				<option value="_current_">Current
				<%
				if (defaultColumns != null)
				{
					%>
					<option value="_default_">Default
					<%
				}
				%>
				<option value="">-- user defined --
				<%
				Enumeration<Integer, String> contexts = sc.getContextNames(itemType, subContext);
				for (int i = 0; i < contexts.size(); ++i)
				{
					ItemContext context = sc.getContext(contexts.getKey(i));
					if (context != null && !ItemContext.DEFAULT_NAME.equals(context.getName()))
					{
						String columns = context.getSetting(settingName);
						String stickyColumn = context.getSetting(settingName+".sticky");
						if (columns != null)
						{
							%>
							<option value="<%=columns%>" 
							<%if (stickyColumn != null){%>
							data-sticky-column="<%=stickyColumn%>"
							<%}%>
							><%=HTML.encodeTags(context.getName())%>
							<%
						}
					}
				}
				%>
			</select>
			</td>
			<%
			if (request.getParameter("nosavedelete") == null)
			{
				%>
				<td><base:button id="btnSavePreset" title="Save as&hellip;" /></td>
				<%
			}
			%>
			</tr>
			</table>
			</td>
		</tr>
		<tr>
		<td colspan="4" >
			<div class="padded" style="text-align: right;">
				<b>×</b> = This column cannot be hidden
			</div>
		</td>
		</tr>
		</table>
		</div>
		</form>
		<base:buttongroup subclass="dialogbuttons">
			<base:button id="btnSave" title="Ok" />
			<base:button id="close" title="Cancel" />
		</base:buttongroup>
	</base:body>
	</base:page>